import 'package:flutter/material.dart';
import 'package:freezed_annotation/freezed_annotation.dart';

import '../../utilities/base_attribute.dart';
import 'border_radius.util.dart';

part 'border_radius.freezed.dart';

/// Short api
final rounded = BorderRadiusUtility(BorderRadiusProperties.all);

/// Border radius attribute
@freezed
class BorderRadiusAttribute extends Attribute with _$BorderRadiusAttribute {
  /// Constructor
  factory BorderRadiusAttribute({
    final Radius? bottomLeft,
    final Radius? bottomRight,
    final Radius? topLeft,
    final Radius? topRight,
  }) = _BorderRadiusAttribute;
}

/// Border radius utility builder
BorderRadiusGeometry? borderRadiusUtilityBuilder(List<Attribute> attributes) {
  var borderRadius = BorderRadiusAttribute();
  for (final attribute in attributes) {
    if (attribute is BorderRadiusAttribute) {
      borderRadius = borderRadius.copyWith(
        topLeft: attribute.topLeft,
        topRight: attribute.topRight,
        bottomLeft: attribute.bottomLeft,
        bottomRight: attribute.bottomRight,
      );
    }
  }

  return BorderRadius.only(
    topLeft: borderRadius.topLeft ?? Radius.zero,
    topRight: borderRadius.topRight ?? Radius.zero,
    bottomLeft: borderRadius.bottomLeft ?? Radius.zero,
    bottomRight: borderRadius.bottomRight ?? Radius.zero,
  );
}
