// ignore: avoid_classes_with_only_static_members
import 'package:flutter/material.dart';

import 'border_radius.dart';

/// Border radius options
class BorderRadiusOptions {
  static final double none = 0;
  static final double small = 4;
  static final double medium = 8;
  static final double large = 16;
  static final double xlarge = 32;
}

/// Possible space properties
enum BorderRadiusProperties {
  all,
  topLeft,
  topRight,
  bottomLeft,
  bottomRight,
}

class BorderRadiusUtility {
  /// Constructor
  const BorderRadiusUtility(this.property);

  final BorderRadiusProperties property;

  /// Set space of all border radius
  BorderRadiusAttribute operator [](double size) => builder(property, size);

  BorderRadiusAttribute get none => builder(property, 0);
  BorderRadiusAttribute get small =>
      builder(property, BorderRadiusOptions.small);
  BorderRadiusAttribute get medium =>
      builder(property, BorderRadiusOptions.medium);
  BorderRadiusAttribute get large =>
      builder(property, BorderRadiusOptions.large);
  BorderRadiusAttribute get xlarge =>
      builder(property, BorderRadiusOptions.xlarge);

  BorderRadiusAttribute builder(BorderRadiusProperties prop, double size) {
    switch (prop) {
      case BorderRadiusProperties.all:
        return BorderRadiusAttribute(
          topLeft: Radius.circular(size),
          topRight: Radius.circular(size),
          bottomLeft: Radius.circular(size),
          bottomRight: Radius.circular(size),
        );
      case BorderRadiusProperties.topLeft:
        return BorderRadiusAttribute(
          topLeft: Radius.circular(size),
        );
      case BorderRadiusProperties.topRight:
        return BorderRadiusAttribute(
          topRight: Radius.circular(size),
        );
      case BorderRadiusProperties.bottomLeft:
        return BorderRadiusAttribute(
          bottomLeft: Radius.circular(size),
        );
      case BorderRadiusProperties.bottomRight:
        return BorderRadiusAttribute(
          bottomRight: Radius.circular(size),
        );

      default:
        return BorderRadiusAttribute();
    }
  }
}
