import 'package:flutter/material.dart';
import 'package:freezed_annotation/freezed_annotation.dart';

import '../../utilities/base_attribute.dart';

part 'color.freezed.dart';

/// Color attribute
@freezed
class ColorAttribute extends Attribute with _$ColorAttribute {
  /// Constructor
  factory ColorAttribute(Color color) = _ColorAttribute;

  /// Background color
  factory ColorAttribute.backgroundColor(Color color) =
      BackgroundColorAttribute;

  /// Text color
  factory ColorAttribute.textColor(Color color) = TextColorAttribute;

  /// Creates instance of type ColorAttribute
  static T create<T extends ColorAttribute>(Color color) {
    switch (T) {
      case BackgroundColorAttribute:
        return BackgroundColorAttribute(color) as T;
      case TextColorAttribute:
        return TextColorAttribute(color) as T;
      default:
        throw Exception('Cannot create ColorAttribute of type $T');
    }
  }
}
