import 'package:freezed_annotation/freezed_annotation.dart';

import '../../utilities/base_attribute.dart';

part 'size.freezed.dart';

/// Border radius attribute
@freezed
class SizeAttribute extends Attribute with _$SizeAttribute {
  /// Constructor
  factory SizeAttribute(
    final double size,
  ) = _SizeAttribute;

  /// Height size attribute
  factory SizeAttribute.height(
    final double size,
  ) = HeightAttribute;

  /// Max Height size attribute
  factory SizeAttribute.maxHeight(
    final double size,
  ) = MaxHeightAttribute;

  /// Min Height size attribute
  factory SizeAttribute.minHeight(
    final double size,
  ) = MinHeightAttribute;

  /// Width size attribute
  factory SizeAttribute.width(
    final double size,
  ) = WidthAttribute;

  /// Max width size attribute
  factory SizeAttribute.maxWidth(
    final double size,
  ) = MaxWidthAttribute;

  /// Min width size attribute
  factory SizeAttribute.minWidth(
    final double size,
  ) = MinWidthAttribute;

  /// Create instance a class of SizeAttribute
  static T create<T extends SizeAttribute>(double size) {
    /// Cannot be SizeAttribute itself
    assert(T != SizeAttribute);

    switch (T) {
      case HeightAttribute:
        return HeightAttribute(size) as T;
      case MaxHeightAttribute:
        return MaxHeightAttribute(size) as T;
      case MinHeightAttribute:
        return MinHeightAttribute(size) as T;
      case WidthAttribute:
        return WidthAttribute(size) as T;
      case MaxWidthAttribute:
        return MaxWidthAttribute(size) as T;
      case MinWidthAttribute:
        return MinWidthAttribute(size) as T;
      default:
        throw Exception('Cannot create SizeAttribute of $T');
    }
  }
}
