import 'package:freezed_annotation/freezed_annotation.dart';

import '../../utilities/base_attribute.dart';

part 'space.freezed.dart';

@freezed

/// Attribute of type space
class SpaceAttribute extends Attribute with _$SpaceAttribute {
  /// Defaut constructor
  factory SpaceAttribute({
    final double? left,
    final double? top,
    final double? right,
    final double? bottom,
  }) = _SpaceAttribute;

  /// Margin constructor
  factory SpaceAttribute.margin({
    final double? left,
    final double? top,
    final double? right,
    final double? bottom,
  }) = MarginAttribute;

  /// Padding constructor
  factory SpaceAttribute.padding({
    final double? left,
    final double? top,
    final double? right,
    final double? bottom,
  }) = PaddingAttribute;

  /// Create instance a class of SpaceeAttrtibute
  static T create<T extends SpaceAttribute>({
    final double? left,
    final double? top,
    final double? right,
    final double? bottom,
  }) {
    assert(T != SpaceAttribute);
    switch (T) {
      case MarginAttribute:
        return MarginAttribute(
          left: left,
          top: top,
          right: right,
          bottom: bottom,
        ) as T;
      case PaddingAttribute:
        return PaddingAttribute(
          left: left,
          top: top,
          right: right,
          bottom: bottom,
        ) as T;

      default:
        throw Exception('Cannot create SpaceAttribute of $T');
    }
  }
}
