import 'package:flutter/material.dart';

import '../../utilities/base_attribute.dart';
import 'space.dart';

/// Default space options
class SpaceOptions {
  static final double none = 0;
  static final double small = 4;
  static final double medium = 8;
  static final double large = 16;
  static final double xlarge = 32;
}

/// Possible space properties
enum SpaceProperty {
  all,
  top,
  bottom,
  left,
  right,
  horizontal,
  vertical,
}

/// Merges attributes of type space

class SpaceUtility<T extends SpaceAttribute> {
  /// Constructor
  const SpaceUtility(this.property);

  final SpaceProperty property;

  /// Sets space for space attribute
  SpaceAttribute operator [](double space) => builder(property, space);

  SpaceAttribute get none => builder(property, 0.0);
  SpaceAttribute get small => builder(property, SpaceOptions.small);
  SpaceAttribute get medium => builder(property, SpaceOptions.medium);
  SpaceAttribute get large => builder(property, SpaceOptions.large);
  SpaceAttribute get xlarge => builder(property, SpaceOptions.xlarge);

  /// Space utility type builder
  T builder(SpaceProperty prop, double space) {
    switch (prop) {
      case SpaceProperty.all:
        return SpaceAttribute.create<T>(
          left: space,
          top: space,
          right: space,
          bottom: space,
        );
      case SpaceProperty.left:
        return SpaceAttribute.create<T>(
          left: space,
        );
      case SpaceProperty.top:
        return SpaceAttribute.create<T>(
          top: space,
        );
      case SpaceProperty.right:
        return SpaceAttribute.create<T>(
          right: space,
        );
      case SpaceProperty.bottom:
        return SpaceAttribute.create<T>(
          bottom: space,
        );
      case SpaceProperty.horizontal:
        return SpaceAttribute.create<T>(
          left: space,
          right: space,
        );
      case SpaceProperty.vertical:
        return SpaceAttribute.create<T>(
          top: space,
          bottom: space,
        );
      default:
        return SpaceAttribute.create<T>();
    }
  }
}

/// Builds a Margin Traits
EdgeInsetsGeometry spaceUtilityBuilder<T extends SpaceAttribute>(
  List<Attribute> attributes,
) {
  assert(T != SpaceAttribute);
  double? left;
  double? top;
  double? right;
  double? bottom;

  for (final attr in attributes) {
    /// Only if its of type T
    if (attr is T) {
      if (attr.left != null) {
        left = attr.left;
      }
      if (attr.top != null) {
        top = attr.top;
      }
      if (attr.right != null) {
        right = attr.right;
      }
      if (attr.bottom != null) {
        bottom = attr.bottom;
      }
    }
  }

  return EdgeInsets.only(
    left: left ?? 0.0,
    right: right ?? 0.0,
    top: top ?? 0.0,
    bottom: bottom ?? 0.0,
  );
}
