import 'package:flutter/material.dart';
import 'package:remix/attributes/color/color.dart';
import 'package:remix/attributes/color/color.util.dart';
import 'package:remix/attributes/space/space.dart';

import '../attributes/align/align.util.dart';
import '../attributes/border_radius/border_radius.dart';
import '../attributes/size/size.dart';
import '../attributes/size/size.util.dart';
import '../attributes/space/space.util.dart';
import 'define_mix.dart';

/// Shape Container
class ShapeContainer extends StatelessWidget {
  /// Constructor
  ShapeContainer(
    this.shape, {
    required this.child,
    Key? key,
  }) : super(key: key);

  /// Define shape
  final Mix shape;

  /// Child widget
  final Widget child;

  @override
  Widget build(BuildContext context) {
    return Container(
      alignment: alignmentUtilityBuilder(shape.params),
      margin: spaceUtilityBuilder<MarginAttribute>(shape.params),
      padding: spaceUtilityBuilder<PaddingAttribute>(shape.params),
      height: sizeUtilityBuilder<HeightAttribute>(shape.params),
      width: sizeUtilityBuilder<WidthAttribute>(shape.params),
      decoration: BoxDecoration(
        borderRadius: borderRadiusUtilityBuilder(shape.params),
        color: colorUtilityBuilder<BackgroundColorAttribute>(shape.params),
      ),
      child: child,
    );
  }
}

//  BoxShadow(
//           color: Colors.grey.withOpacity(0.7),
//           spreadRadius: 0,
//           blurRadius: 1,
//           offset: Offset(0, 1), // changes position of shadow
//         ),

// BoxShadow(
//           color: Colors.grey.withOpacity(0.7),
//           spreadRadius: 1,
//           blurRadius: 2,
//           offset: Offset(0, 2), // changes position of shadow
//         ),

// BoxShadow(
//     color: Colors.grey.withOpacity(0.7),
//     spreadRadius: 1,
//     blurRadius: 4,
//     offset: Offset(0, 4), // changes position of shadow
//   ),

//  BoxShadow(
//             color: Colors.grey.withOpacity(0.7),
//             spreadRadius: 1,
//             blurRadius: 7,
//             offset: Offset(0, 5), // changes position of shadow
//           ),

//  BoxShadow(
//             color: Colors.grey.withOpacity(0.7),
//             spreadRadius: 2,
//             blurRadius: 10,
//             offset: Offset(0, 8), // changes position of shadow
//           ),
